@@ -14,18 +14,13 @@ class BaseLang:
 
     :param file_path: Path to preferred local file destination.
         If the file does not exist at the specified path, it will be created
-    :type file_path: str
     :param default_dictionary: Default local file path ``str`` or ``dict``
         that will be used for local file start values, defaults to ``{}`` *(empty dict)*
-    :type default_dictionary: Union[str, dict], optional
     :param auto_file_creation: Automatic local file creation on object initialization, defaults to True
-    :type auto_file_creation: bool, optional
     :param force_overwrite_file: Whether the file needs to be overwritten if it already exists, defaults to False
-    :type force_overwrite_file: bool, optional
     :param parser_write_kwargs: Pass custom arguments to parser's *write to local file* action, defaults to ``{}`` *(empty dict)*
-    :type parser_write_kwargs: dict, optional
     :param parser_read_kwargs: Pass custom arguments to parser's *read from local file* action, defaults to ``{}`` *(empty dict)*
-    :type parser_read_kwargs: dict, optional
+
     :raises ValueError: If provided data type in argument ``default_dictionary`` can't
         be represented as path ``str`` or ``dict``
 
@@ -45,7 +40,13 @@ class BaseLang:
     __parser_write_kwargs = {}
     __parser_read_kwargs = {}
 
-    def __init__(self, file_path: str, default_dictionary={}, auto_file_creation=True, force_overwrite_file=False, parser_write_kwargs={}, parser_read_kwargs={}):
+    def __init__(
+        self,
+        file_path: str,
+        default_dictionary: dict = {},
+        auto_file_creation: bool = True, force_overwrite_file: bool = False,
+        parser_write_kwargs: dict = {}, parser_read_kwargs: dict = {}
+    ):
         self.local_file_path = file_path
         self.parser_write_kwargs = parser_write_kwargs
         self.parser_read_kwargs = parser_read_kwargs
@@ -95,9 +96,8 @@ class BaseLang:
             all references to original dictionary. Disabling this will lead
             to saving the references of the nested dictionaries to the copy object,
             defaults to True.
-        :type deep_mode: bool, optional
+
         :return: ``dictionary`` copy
-        :rtype: dict
         """
         if deep_mode:
             return deepcopy(self.__parsed_dict)
@@ -108,12 +108,10 @@ class BaseLang:
         """Get key from object's ``dictionary``
 
         :param key: Key name
-        :type key: str
         :param default: Default value, if key was not found, defaults to None
-        :type default: Any
+
         :return: Value of requested ``key``, or ``default`` value
             if key wasn't found.
-        :rtype: Any
         """
         return self.__parsed_dict.get(key, default)
 
@@ -121,7 +119,6 @@ class BaseLang:
         """Get items of the object's ``dictionary``
 
         :return: Items of the ``dictionary`` ((key, value) pairs)
-        :rtype: list
         """
         return self.__parsed_dict.items()
 
@@ -129,7 +126,6 @@ class BaseLang:
         """Get keys of the object's ``dictionary``
 
         :return: Keys of the ``dictionary`` (, key)
-        :rtype: list
         """
         return self.__parsed_dict.keys()
 
@@ -137,20 +133,17 @@ class BaseLang:
         """Get values of the object's ``dictionary``
 
         :return: Values of the ``dictionary`` (, value)
-        :rtype: list
         """
         return self.__parsed_dict.values()
 
-    def pop(self, key: Any, default=None) -> Any:
+    def pop(self, key: str, default=None) -> Any:
         """Pop key from object's ``dictionary``
 
         :param key: Key name
-        :type key: Any
         :param default: Default value, if key was not found, defaults to None
-        :type default: Any, optional
+
         :return: Value of requested ``key``, or ``default`` value
             if key wasn't found, defaults to None.
-        :rtype: Any
         """
         return self.__parsed_dict.pop(key, default)
 
@@ -158,27 +151,23 @@ class BaseLang:
         """Pop item from object's ``dictionary`` in LIFO order.
 
         :param key: Key name
-        :type key: Any
         :param default: Default value, if key was not found, defaults to None
-        :type default: Any, optional
+
         :return: Value of requested ``key``, or ``default`` value
             if key wasn't found, defaults to None.
-        :rtype: Any
         """
         return self.__parsed_dict.popitem()
 
-    def setdefault(self, key: Any, default=None) -> Any:
+    def setdefault(self, key: str, default=None) -> Any:
         """
         If key is in the object's ``dictionary``, return its value.
         If not, insert key with a value of ``default`` and return ``default``
 
         :param key: Name of the key
-        :type key: Any
         :param default: Default value, defaults to None
-        :type default: Any, optional
+
         :return: If key is in the dictionary, return its value, else:
             returns ``defalut``
-        :rtype: Any
         """
         return self.__parsed_dict.setdefault(key, default)
 
@@ -187,7 +176,6 @@ class BaseLang:
 
         :param dictionary: Dictionary, that will be merged to
             ``dictionary``
-        :type dictionary: dict
         """
         self.__parsed_dict.update(dictionary)
 
@@ -196,9 +184,7 @@ class BaseLang:
         """Arguments that will be passed to parser on *write to file* action.
         This property can be modified. Note that only ``dict`` type is allowed.
 
-        :type: dict
         :return: already specified arguments
-        :rtype: dict
         """
         return self.__parser_write_kwargs
 
@@ -214,9 +200,7 @@ class BaseLang:
         """Arguments that will be passed to parser on *read from file* action.
         This property can be modified. Note that only ``dict`` type is allowed.
 
-        :type: dict
         :return: already specified arguments
-        :rtype: dict
         """
         return self.__parser_read_kwargs
 
@@ -233,7 +217,6 @@ class BaseLang:
         Contains local file data parsed to dictionary
 
         :return: ``dictionary`` attribute
-        :rtype: dict
         """
         return self.__parsed_dict
 
@@ -251,7 +234,6 @@ class BaseLang:
         specified in ``default_dictionary`` argument.
 
         :return: default dictionary
-        :rtype: dict
         """
         return self.__default_dict
 
@@ -275,10 +257,9 @@ class BaseLang:
             simple ``dict.update()`` method call. So if you don't care about nested
             dictionaries be overwritten, you can disable this feature to boost the
             execution speed
-        :type safe_mode: bool, optional
+
         :return: Status of local file read action. If file does not exist -
             ``False`` will be returned.
-        :rtype: bool
         """
         if not self.file_exists():
             return False
@@ -296,7 +277,6 @@ class BaseLang:
 
         :return: Status of local file read action. If file does not exist -
             ``False`` will be returned.
-        :rtype: bool
         """
         if self.file_exists():
             self.__parsed_dict = self.read_file_as_dict()
@@ -315,7 +295,6 @@ class BaseLang:
         """Create new local file from default dictionary
 
         :return: Was the file created successfully
-        :rtype: bool
         """
         self.write_dict_to_file(self.__default_dict)
 
@@ -326,7 +305,6 @@ class BaseLang:
 
         :return: Was the file removed.
             False will be returned only if the local file does not exist at the time of deletion.
-        :rtype: bool
         """
         if self.file_exists():
             remove(self.local_file_path)
@@ -336,16 +314,12 @@ class BaseLang:
 
     def is_file_exist(self) -> bool:
         """
-        Deprecated in ``2.3.0``, use ``.file_exists()`` method instead
+        Deprecated in ``2.3.0``, use ``.file_exists()`` method instead.
+        This method will be removed in ``3.0.0`` release.
 
         Check local file existence.
 
         :return: Does the file exist
-        :rtype: bool
-
-        .. deprecated:: 2.3.0
-           This method will be removed in ``3.0.0`` release.
-           Use ``.file_exists()`` method instead
         """
         deprecation_mark(
             'Method was deprecated in version "2.3.0" and will be '
@@ -357,7 +331,6 @@ class BaseLang:
         """Check local file existence
 
         :return: Does the file exist
-        :rtype: bool
         """
         return path.isfile(self.local_file_path)
 
@@ -365,7 +338,6 @@ class BaseLang:
         """Write dict from ``dictionary`` argument to local file bound to this object
 
         :param dictionary: Dictionary that should be written to file
-        :type dictionary: dict
         """
         create_directories(self.local_file_path)
         self._core__write_dict_to_file(self.local_file_path, dictionary)
@@ -374,7 +346,6 @@ class BaseLang:
         """Read local file bound to this object as dictionary
 
         :return: Parsed to dictionary local file
-        :rtype: dict
         """
         return self._core__read_file_to_dict(self.local_file_path)
 
@@ -382,9 +353,9 @@ class BaseLang:
         """Template for reading local file as dictionary
 
         :param file_path: Path to local file
-        :type file_path: str
+
         :return: Parsed local file dictionary
-        :rtype: dict
+
         :raises NotImplementedError: If method was not implemented directly in inherited class
         """
         raise NotImplementedError("This core method should be implemented directly in {}".format(self.__class__.__name__))
@@ -393,9 +364,9 @@ class BaseLang:
         """Template for dumping dictionary to local file
 
         :param file_path: Path to local file
-        :type file_path: str
+
         :param dictionary: Dictionary which will be written in ``file_path``
-        :type dictionary: dict
+
         :raises NotImplementedError: If method was not implemented directly in inherited class
         """
         raise NotImplementedError("This core method should be implemented directly in {}".format(self.__class__.__name__))
@@ -405,9 +376,8 @@ def create_directories(path_to_use: str, path_is_dir=False):
     """Create all directories from path
 
     :param path_to_use: The path to be created
-    :type path_to_use: str
+
     :param path_is_dir: Is ``path_to_use`` ends with directory, defaults to False
-    :type path_is_dir: bool, optional
     """
     path_to_use = path_to_use if path_is_dir else path.dirname(path_to_use)
 
@@ -422,11 +392,10 @@ def recursive_dicts_merge(merge_from: dict, merge_to: dict) -> dict:
     keys removal of nested dictionaries.
 
     :param merge_from: Dictionary to merge keys from
-    :type merge_from: dict
+
     :param merge_to: Dictionary to merge keys to
-    :type merge_to: dict
+
     :return: Dictionary with all ``merge_from`` keys merged into ``merge_to``
-    :rtype: dict
 
     .. note::
         ``merge_from`` and ``merge_to`` dictionaries will not be modified in process of execution.
@@ -453,6 +422,5 @@ def deprecation_mark(deprecation_note: str) -> None:
 
     :param deprecation_note: What and when was deprecated message,
                              that will be collected by loggers
-    :type deprecation_note: str
     """
     warn(deprecation_note, DeprecationWarning)
